==> zio-aws-route53recoverycontrolconfig_3-5.17.130.3-sources.jar: zio/aws/route53recoverycontrolconfig/model/NewAssertionRule.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class NewAssertionRule(
    assertedControls: Iterable[__stringMin1Max256PatternAZaZ09],
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    name: __stringMin1Max64PatternS,
    ruleConfig: zio.aws.route53recoverycontrolconfig.model.RuleConfig,
    waitPeriodMs: __integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule = {
    import NewAssertionRule.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule
      .builder()
      .assertedControls(assertedControls.map { item =>
        __stringMin1Max256PatternAZaZ09.unwrap(item): java.lang.String
      }.asJavaCollection)
      .controlPanelArn(
        __stringMin1Max256PatternAZaZ09.unwrap(
          controlPanelArn
        ): java.lang.String
      )
      .name(__stringMin1Max64PatternS.unwrap(name): java.lang.String)
      .ruleConfig(ruleConfig.buildAwsValue())
      .waitPeriodMs(__integer.unwrap(waitPeriodMs): Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.NewAssertionRule.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.NewAssertionRule
      .wrap(buildAwsValue())
}
object NewAssertionRule {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.NewAssertionRule =
      zio.aws.route53recoverycontrolconfig.model.NewAssertionRule(
        assertedControls,
        controlPanelArn,
        name,
        ruleConfig.asEditable,
        waitPeriodMs
      )
    def assertedControls: List[__stringMin1Max256PatternAZaZ09]
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def name: __stringMin1Max64PatternS
    def ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    def waitPeriodMs: __integer
    def getAssertedControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(assertedControls)
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getRuleConfig: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    ] = ZIO.succeed(ruleConfig)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule
  ) extends zio.aws.route53recoverycontrolconfig.model.NewAssertionRule.ReadOnly {
    override val assertedControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .assertedControls()
      .asScala
      .map { item =>
        zio.aws.route53recoverycontrolconfig.model.primitives
          .__stringMin1Max256PatternAZaZ09(item)
      }
      .toList
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max256PatternAZaZ09(impl.controlPanelArn())
    override val name: __stringMin1Max64PatternS =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max64PatternS(impl.name())
    override val ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
      zio.aws.route53recoverycontrolconfig.model.RuleConfig
        .wrap(impl.ruleConfig())
    override val waitPeriodMs: __integer =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__integer(impl.waitPeriodMs())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule
  ): zio.aws.route53recoverycontrolconfig.model.NewAssertionRule.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_3-5.17.295.17-sources.jar: zio/aws/route53recoverycontrolconfig/model/NewAssertionRule.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class NewAssertionRule(
    assertedControls: Iterable[__stringMin1Max256PatternAZaZ09],
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    name: __stringMin1Max64PatternS,
    ruleConfig: zio.aws.route53recoverycontrolconfig.model.RuleConfig,
    waitPeriodMs: __integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule = {
    import NewAssertionRule.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule
      .builder()
      .assertedControls(assertedControls.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .controlPanelArn(controlPanelArn: java.lang.String)
      .name(name: java.lang.String)
      .ruleConfig(ruleConfig.buildAwsValue())
      .waitPeriodMs(waitPeriodMs: Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.NewAssertionRule.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.NewAssertionRule
      .wrap(buildAwsValue())
}
object NewAssertionRule {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.NewAssertionRule =
      zio.aws.route53recoverycontrolconfig.model.NewAssertionRule(
        assertedControls,
        controlPanelArn,
        name,
        ruleConfig.asEditable,
        waitPeriodMs
      )
    def assertedControls: List[__stringMin1Max256PatternAZaZ09]
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def name: __stringMin1Max64PatternS
    def ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    def waitPeriodMs: __integer
    def getAssertedControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(assertedControls)
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getRuleConfig: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    ] = ZIO.succeed(ruleConfig)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule
  ) extends zio.aws.route53recoverycontrolconfig.model.NewAssertionRule.ReadOnly {
    override val assertedControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .assertedControls()
      .asScala
      .map { item =>
        item: __stringMin1Max256PatternAZaZ09
      }
      .toList
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      impl.controlPanelArn(): __stringMin1Max256PatternAZaZ09
    override val name: __stringMin1Max64PatternS =
      impl.name(): __stringMin1Max64PatternS
    override val ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
      zio.aws.route53recoverycontrolconfig.model.RuleConfig
        .wrap(impl.ruleConfig())
    override val waitPeriodMs: __integer = impl.waitPeriodMs(): __integer
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewAssertionRule
  ): zio.aws.route53recoverycontrolconfig.model.NewAssertionRule.ReadOnly =
    new Wrapper(impl)
}
